@@ -124,9 +124,11 @@ def pexist(d):
     return pexists(d)
 
 
-def clone(url, depth=1, dst_dir='.'):
+def clone(url, depth=1, dst_dir='.', reclone=False):
     dst_dir = expanduser(dst_dir)
     if dst_dir != '.' and pexist(dst_dir):
+        if not reclone:
+            return
         run(f'rm -rf {dst_dir}')
 
     def _clone():
@@ -154,24 +156,12 @@ def sort_by_mtime(files: list):
 def backup(source, max_count=5):
     source = expanduser(source)
     if not pexist(source):
-        err(f'{source} not exist')
+        warn(f'backup: {source} not exist')
         return
-    basename = os.path.basename(source)
-    dname = os.path.dirname(source)
-    if '.' in basename:
-        *backup_basename, _type = basename.split('.')
-        backup_basename = '.'.join(backup_basename)
-    else:
-        backup_basename = basename
-        _type = None
-    backup_name = os.path.join(dname, backup_basename)
     backup_files = []
     full = True
     for i in range(1, max_count + 1):
-        if _type is None:
-            new_name = backup_name + f'_{i}'
-        else:
-            new_name = backup_name + f'_{i}.{_type}'
+        new_name = source + f'.{i}'
         if not pexist(new_name):
             backup_name = new_name
             full = False
